@@ -43,6 +43,8 @@
 #include <kaction.h>
 #include <ktoolbarbutton.h>
 
+#include <qpopupmenu.h>
+
 using Tellico::Controller;
 
 Controller* Controller::s_self = 0;
@@ -134,6 +136,8 @@ void Controller::slotCollectionAdded(Data::CollPtr coll_) {
   m_selectedEntries.clear();
   m_mainWindow->slotEntryCount();
 
+  emit collectionAdded(coll_->type());
+
   updateActions();
 
   connect(coll_, SIGNAL(signalGroupsModified(Tellico::Data::CollPtr, PtrVector<Tellico::Data::EntryGroup>)),
@@ -178,7 +182,6 @@ void Controller::addedEntries(Data::EntryVec entries_) {
     it->addEntries(entries_);
   }
   m_mainWindow->slotQueueFilter();
-  slotUpdateSelection(0, entries_);
   blockAllSignals(false);
 }
 
@@ -220,7 +223,7 @@ void Controller::addedField(Data::CollPtr coll_, Data::FieldPtr field_) {
 }
 
 void Controller::removedField(Data::CollPtr coll_, Data::FieldPtr field_) {
-//  myDebug() << "Controller::slotFieldDeleted() - " << field_->name() << endl;
+//  myDebug() << "Controller::removedField() - " << field_->name() << endl;
   for(ObserverVec::Iterator it = m_observers.begin(); it != m_observers.end(); ++it) {
     it->removeField(coll_, field_);
   }
@@ -258,7 +261,7 @@ void Controller::slotClearSelection() {
   if(m_mainWindow->m_loanView) {
     m_mainWindow->m_loanView->clearSelection();
   }
-  m_mainWindow->m_editDialog->clear();
+//  m_mainWindow->m_editDialog->clear(); let this stay
 //  m_mainWindow->m_viewStack->clear(); let this stay
 
   blockAllSignals(false);
@@ -454,6 +457,7 @@ void Controller::slotDeleteSelectedEntries() {
 //    newList.append(static_cast<EntryItem*>(it.current())->entry());
 //  }
 //  slotUpdateSelection(m_mainWindow->m_detailedView, newList);
+  slotClearSelection();
 }
 
 void Controller::slotRefreshField(Data::FieldPtr field_) {
@@ -505,10 +509,13 @@ void Controller::slotUpdateFilter(FilterPtr filter_) {
 //  myDebug() << "Controller::slotUpdateFilter()" << endl;
   blockAllSignals(true);
 
+  if(filter_ && !filter_->isEmpty()) {
+    // only clear the selection if there's actually a filter rule
+    m_mainWindow->m_detailedView->clearSelection();
+    m_mainWindow->m_viewStack->iconView()->clearSelection();
+    m_selectedEntries.clear();
+  }
   updateActions();
-//  m_selectedEntries.clear();
-//  m_mainWindow->m_detailedView->clearSelection();
-//  m_mainWindow->m_viewStack->iconView()->clearSelection();
 
   // the view takes over ownership of the filter
   m_mainWindow->m_detailedView->setFilter(filter_);
