@@ -674,8 +674,8 @@ Tellico::Data::EntryPtr IMDBFetcher::parseEntry(const QString& str_) {
   doAlsoKnownAs(str_, entry);
   doPlot(str_, entry, m_url);
   doLists(str_, entry);
-  doPerson(str_, entry, QString::fromLatin1("Directed"), QString::fromLatin1("director"));
-  doPerson(str_, entry, QString::fromLatin1("Writing"), QString::fromLatin1("writer"));
+  doPerson(str_, entry, QString::fromLatin1("Direct"), QString::fromLatin1("director"));
+  doPerson(str_, entry, QString::fromLatin1("Writ"), QString::fromLatin1("writer"));
   doRating(str_, entry);
   doCast(str_, entry, m_url);
   if(m_fetchImages) {
@@ -753,6 +753,10 @@ void IMDBFetcher::doAlsoKnownAs(const QString& str_, Data::EntryPtr entry_) {
     QStringList values;
     for(QStringList::Iterator it = list.begin(); it != list.end(); ++it) {
       QString s = *it;
+      // sometimes, the word "more" gets linked to the releaseinfo page, check that
+      if(s.find(QString::fromLatin1("releaseinfo")) > -1) {
+        continue;
+      }
       s.remove(*s_tagRx);
       s.remove(brackRx);
       s = s.stripWhiteSpace();
@@ -819,12 +823,16 @@ void IMDBFetcher::doPerson(const QString& str_, Data::EntryPtr entry_,
   int pos = str_.find(imdbHeader_);
   if(pos > -1) {
     QStringList people;
-    // loop until repeated <br> tags
+    // loop until repeated <br> tags or </div> tag
     QRegExp br2Rx(QString::fromLatin1("<br[\\s/]*>\\s*<br[\\s/]*>"), false);
     br2Rx.setMinimal(true);
+    QRegExp divRx(QString::fromLatin1("<[/]*div"), false);
+    divRx.setMinimal(true);
 
     const QString name = QString::fromLatin1("/name/");
-    const int endPos = str_.find(br2Rx, pos);
+    const int endPos1 = str_.find(br2Rx, pos);
+    const int endPos2 = str_.find(divRx, pos);
+    const int endPos = QMIN(endPos1, endPos2); // ok to be -1
     pos = s_anchorRx->search(str_, pos+1);
     while(pos > -1 && pos < endPos) {
       if(s_anchorRx->cap(1).find(name) > -1) {
@@ -984,13 +992,20 @@ void IMDBFetcher::doLists(const QString& str_, Data::EntryPtr entry_) {
   const QString soundMix = QString::fromLatin1("sound-mix=");
   const QString year = QString::fromLatin1("/Years/");
 
+  // IIMdb also has links with the word "sections" in them, remove that
+  // for genres and nationalities
+
   QStringList genres, countries, langs, certs, tracks;
   for(int pos = s_anchorRx->search(str_); pos > -1; pos = s_anchorRx->search(str_, pos+1)) {
     const QString cap1 = s_anchorRx->cap(1);
     if(cap1.find(genre) > -1) {
-      genres += s_anchorRx->cap(2);
+      if(s_anchorRx->cap(2).find(QString::fromLatin1(" section"), 0, false) == -1) {
+        genres += s_anchorRx->cap(2);
+      }
     } else if(cap1.find(country) > -1) {
-      countries += s_anchorRx->cap(2);
+      if(s_anchorRx->cap(2).find(QString::fromLatin1(" section"), 0, false) == -1) {
+        countries += s_anchorRx->cap(2);
+      }
     } else if(cap1.find(lang) > -1) {
       langs += s_anchorRx->cap(2);
     } else if(cap1.find(colorInfo) > -1) {
